@@ -19,13 +19,13 @@
 #' @param ...
 #'   Additional arguments to be passed to the fitness function.
 #' @param popSize 'integer' count.
-#'   Population size
+#'   Population size that is distributed evenly between islands.
 #' @param numIslands 'integer' count.
 #'   Number of islands
 #' @param migrationRate 'numeric' number.
 #'   Proportion of individuals that should migrate between islands.
 #' @param migrationInterval 'integer' count.
-#'   Number of iterations at which exchange of individuals takes place.
+#'   Number of generations at which exchange of individuals (or migration) takes place.
 #'   This interval between migrations is called an \emph{epoch}.
 #' @param pcrossover 'numeric' number.
 #'   Probability of crossover between pairs of chromosomes.
@@ -35,7 +35,7 @@
 #'   Number of chromosomes to survive into the next generation.
 #'   Defaults to 5-percent of the island population.
 #' @param maxiter 'integer' count.
-#'   Maximum number of iterations to run before the GA search is halted.
+#'   Maximum number of generations to run on each island before the GA search is halted.
 #' @param run 'integer' count.
 #'   Number of consecutive generations without any improvement in the
 #'   \dQuote{best} fitness value before the GA is stopped.
@@ -58,7 +58,7 @@
 #' @details The fitness function (see \code{Fitness} argument) is solved using
 #'   the \code{\link[GA]{gaisl}} function in the \pkg{GA} package (Scrucca, 2013, 2016).
 #'   The function implements an islands evolution model (first proposed by Cohoon and others, 1987).
-#'   to maximize a fitness function using islands genetic algorithms (ISLGAs)
+#'   to maximize a fitness function using islands parallel genetic algorithms (ISLPGAs)
 #'   (Luke, 2013, p. 103-104; Scrucca, 2016, p. 197-200).
 #'   Independent GAs are configured to use integer chromosomes
 #'   represented with a binary codification, linear-rank selection,
@@ -68,12 +68,12 @@
 #'   \describe{
 #'     \item{\code{call}}{original call which can be used for later re-use.}
 #'     \item{\code{solution}}{a 'matrix' representation of the best solution found.
-#'       Each row represents a unique solution giving the best fitness at the final iteration.
+#'       Each row represents a unique solution giving the best fitness at the final generation.
 #'       More than one row indicates a non-unique solution.
 #'       The number of columns is equal to the subset size \code{k}.}
-#'     \item{\code{ga_output}}{output from the ISLGAs,
+#'     \item{\code{ga_output}}{output from the ISLPGAs,
 #'       see \code{\link[=gaisl-class]{gaisl-class}} for format description.}
-#'     \item{\code{ga_time}}{time required to run the ISLGAs,
+#'     \item{\code{ga_time}}{time required to run the ISLPGAs,
 #'       see \code{\link{system.time}} for details.}
 #'   }
 #'
@@ -90,10 +90,12 @@
 #'   available for free at \url{https://cs.gmu.edu/~sean/book/metaheuristics/}.
 #'
 #'   Scrucca, Luca, 2013, GA: A Package for Genetic Algorithms in R:
-#'   Journal of Statistical Software, v. 53, no. 4, p. 1-37.
+#'   Journal of Statistical Software, v. 53, no. 4, p. 1-37,
+#'   \url{http://dx.doi.org/10.18637/jss.v053.i04}.
 #'
 #'   Scrucca, Luca, 2017, On some extensions to GA package: hybrid optimisation,
-#'   parallelisation and islands evolution: The R Journal, v. 9, no. 1, p. 187-206.
+#'   parallelisation and islands evolution: The R Journal, v. 9, no. 1, p. 187-206,
+#'   \url{https://journal.r-project.org/archive/2017/RJ-2017-008}.
 #'
 #' @keywords optimize
 #'
@@ -124,7 +126,7 @@
 FindOptimalSubset <- function(n, k, Fitness, ..., popSize=100, numIslands=4,
                               migrationRate=0.1, migrationInterval=10,
                               pcrossover=0.8, pmutation=0.1,
-                              elitism=max(1, round(popSize/numIslands*0.05)),
+                              elitism=max(1, round(popSize / numIslands * 0.05)),
                               maxiter=1000, run=maxiter, suggestions=NULL,
                               parallel=TRUE, monitor=NULL, seed=NULL) {
 
@@ -140,7 +142,7 @@ FindOptimalSubset <- function(n, k, Fitness, ..., popSize=100, numIslands=4,
   checkmate::assertNumber(pmutation, lower=0, upper=1, finite=TRUE)
   checkmate::assertInt(elitism, lower=1)
   checkmate::assertInt(maxiter, lower=1)
-  checkmate::assertInt(run, lower=1, upper=maxiter)
+  checkmate::assertInt(run, lower=1)
   checkmate::assertMatrix(suggestions, min.rows=1, min.cols=1, null.ok=TRUE)
   checkmate::qassert(parallel, c("B1", "X1[0,)"))
   checkmate::assertFunction(monitor, null.ok=TRUE)
@@ -157,7 +159,7 @@ FindOptimalSubset <- function(n, k, Fitness, ..., popSize=100, numIslands=4,
     if (k < ncol(m)) {
       m <- m[, seq_len(k), drop=FALSE]
     } else if (k > ncol(m)) {
-      set.seed(seed)
+      if (!is.null(seed)) set.seed(seed)
       m <- cbind(m, t(apply(m, 1, function(x) sample(seq_len(n)[-x], k - ncol(m)))))
     }
     suggestions <- t(apply(m, 1, function(x) EncodeChromosome(x, n)))
